Display a checkbox widget. Returns an interaction flag (user interacted with the widget) and the current widget state (checked or not after user interaction).

```python
was_clicked, my_value = gs.ImGuiCheckBox('My value', my_value)
```
